# MNHPy
Meso-NH Python library to plot quick figures

Gallery and script examples : http://mesonh.aero.obs-mip.fr/mesonh55/PythonLIB

Notebook Tutorial in /examples

Feel free to contribute !


# Install
- clone or download the repo
- pip install [--user] MNHPy
